pub enum OciError {
RepoNotFound {
message: String,
},
InvalidHandle {
handle: u64,
},
NoSuchImage {
image: String,
},
InternalError {
message: String,
},
}Expand description
Errors that may be returned by the org.composefs.Oci interface.
Variants
RepoNotFound
The repository could not be found or opened at the configured path.
InvalidHandle
The given handle does not refer to an open repository.
NoSuchImage
The named OCI image/reference does not exist.
InternalError
An unexpected internal error occurred while servicing the request.